.. :changelog:

History
-------

0.1.0 (2018-04-10)
++++++++++++++++++

* Models for Phenotype Ontologies
* REST API
* GraphQL Nodes
* Sync methods for PURL of MONDO, HPO, NCIT

0.1.1 (2018-04-10)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-phenotype-ontologies/compare/v0.1.0...v0.1.1>`_

* Updated sync to sync_ontology to make it more descriptive

0.1.2 (2018-04-10)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-phenotype-ontologies/compare/v0.1.1...v0.1.2>`_

* Added better support for MONDO. A few oddities were causing errors w/ pronto.

0.1.3 (2018-04-18)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-phenotype-ontologies/compare/v0.1.2...v0.1.3>`_

* Updated 3rd party libs

0.1.4 (2018-05-16)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-phenotype-ontologies/compare/v0.1.3...v0.1.4>`_

* Updated setup.py to read from requirements.txt


0.2.0 (2018-06-01)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-phenotype-ontologies/compare/v0.1.4...v0.2.0>`_

* Removed support for GraphQL

0.2.1 (2018-07-27)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-phenotype-ontologies/compare/v0.2.0...v0.2.1>`_

* Updated NCIT to be OncoTree - since we are using the onco tree specific ontology

0.2.2 (2018-08-13)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-phenotype-ontologies/compare/v0.2.1...v0.2.2>`_

* Updated 3rd party requirements. Some requirements had changed so it was causing failures

0.2.3 (2018-10-29)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-phenotype-ontologies/compare/v0.2.2...v0.2.3>`_

* Updated 3rd party requirements.
